"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const nd_gpio_rf_1 = require("nd-gpio-rf");
class GpioRFIn {
    constructor(RED, node, config) {
        this.RED = RED;
        this.config = config;
        this.node = node;
        this.init();
    }
    init() {
        this.node.status({});
        if (this.config.pin) {
            this.gpio = new nd_gpio_rf_1.GpioRF();
            this.node.status({ fill: "green", shape: "dot", text: "connected" });
        }
        this.node.on('input', (msg) => {
            if (this.gpio)
                this.recvRFCode(msg);
            else
                this.node.status({ fill: "red", shape: "dot", text: "no connected pin" });
        });
        this.node.on('close', () => {
        });
    }
    recvRFCode(msg) {
        console.log("Start Sniff......");
        this.node.status({ fill: "yellow", shape: "dot", text: "sniffing" });
        this.gpio.sniff({
            pin: this.config.pin,
            fn_values: this.config.fnValues,
            fn_micros: this.config.fnMicros,
            max_count: this.config.maxCount,
            timeout: this.config.timeout
        }, (error, done) => {
            if (!error) {
                msg.payload = {
                    pin: this.config.pin,
                    fn_values: this.config.fnValues,
                    fn_micros: this.config.fnMicros,
                    max_count: this.config.maxCount,
                    timeout: this.config.timeout
                };
                this.node.status({ fill: "green", shape: "dot", text: "sniff OK" });
                this.node.send(msg);
            }
            else {
                this.node.error(error);
                this.node.status({ fill: "red", shape: "dot", text: error });
            }
        });
        return true;
    }
}
GpioRFIn.MAX_SIGNAL_LEN = 2000;
module.exports = (RED) => {
    function CreateNode(config) {
        RED.nodes.createNode(this, config);
        new GpioRFIn(RED, this, config);
    }
    RED.nodes.registerType("gpio-rf-sniffer", CreateNode);
};
